@@ -67,7 +67,7 @@ sub main {
 		my ($file, $item);
 		foreach $file (@{$matchset}) {
 			$item = new FAQ::OMatic::Item($file);
-			$rt .= FAQ::OMatic::Appearance::itemStart($params);
+			$rt .= FAQ::OMatic::Appearance::itemStart($params, $item);
 			$rt .= $item->displaySearchContext($params);
 		}
 		$rt .= FAQ::OMatic::Appearance::itemEnd($params);
@@ -79,11 +79,14 @@ sub main {
 			."to the database.<p>\n";
 	}
 
-	$rt.=FAQ::OMatic::button(
-		FAQ::OMatic::makeAref('faq', {'_minMatches'=>'','search'=>''}),
-		'Return to FAQ');
+	$rt.=FAQ::OMatic::Help::helpFor($params,
+		'Search Tips', "<br>");
+
+#	$rt.=FAQ::OMatic::button(
+#		FAQ::OMatic::makeAref('faq', {'_minMatches'=>'','search'=>''}),
+#		'Return to FAQ');
 	
-	$rt .= FAQ::OMatic::pageFooter();
+	$rt .= FAQ::OMatic::pageFooter($params, ['search', 'faq']);
 
 	print $rt;
 
