@@ -98,51 +98,14 @@ sub main {
 	$item->setProperty('AttributionsTogether',
 		defined $params->{'_AttributionsTogether'} ? 1 : '');
 
-	if ($params->{'_addDirectory'}) {
-		$item->makeDirectory()->
-			setText("Subcategories:\n\nAnswers in this category:\n");
-	}
-
-	if (defined $params->{'_Moderator'}) {
-		my $rd = FAQ::OMatic::Auth::ensurePerm($item, 'PermModOptions',
-			'editItem', $cgi, 1);
-		if ($rd) { print $rd; exit 0; }
-
-		if (defined $params->{'_Moderator'}) {
-			$item->setProperty('Moderator', $params->{'_Moderator'});
-		}
-		if (defined $params->{'_MailModerator'}) {
-			$item->setProperty('MailModerator', $params->{'_MailModerator'});
-		}
-		if (defined $params->{'_PermAddPart'}) {
-			$item->setProperty('PermAddPart', $params->{'_PermAddPart'});
-		}
-		if (defined $params->{'_PermUseHTML'}) {
-			$item->setProperty('PermUseHTML', $params->{'_PermUseHTML'});
-		}
-		if (defined $params->{'_PermEditPart'}) {
-			$item->setProperty('PermEditPart', $params->{'_PermEditPart'});
-		}
-		if (defined $params->{'_PermEditItem'}) {
-			$item->setProperty('PermEditItem', $params->{'_PermEditItem'});
-		}
-		if (defined $params->{'_PermModOptions'}) {
-			$item->setProperty('PermModOptions', $params->{'_PermModOptions'});
-		}
-	}
+# TODO: delete this block. superseded by submitAnsToCat.
+#	if ($params->{'_addDirectory'}) {
+#		$item->makeDirectory()->
+#			setText("Subcategories:\n\nAnswers in this category:\n");
+#	}
 
 	$item->saveToFile();
 
-#	# If title changed, cached copy of parent item will have the wrong
-#	# name for the link to this item.
-#	# TODO: As will any see-also links,
-#	# TODO: but I don't have a solution for that offhand.
-#	my $parent = $item->getParent();
-#	if ($parent ne $item) {
-#		$parent->saveToFile();		# update cached copy of parent
-#	}
-# fixing TODO: testing by turning off this hack
-
 	$item->notifyModerator($cgi, 'edited the item configuration');
 
 	my $url;
